# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/widgets/currency.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_currencyWidget(object):
    def setupUi(self, currencyWidget):
        currencyWidget.setObjectName("currencyWidget")
        currencyWidget.resize(748, 719)
        self.verticalLayout = QtWidgets.QVBoxLayout(currencyWidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.refreshButton = QtWidgets.QPushButton(currencyWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.refreshButton.sizePolicy().hasHeightForWidth())
        self.refreshButton.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/refresh_icon"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refreshButton.setIcon(icon)
        self.refreshButton.setObjectName("refreshButton")
        self.verticalLayout.addWidget(self.refreshButton, 0, QtCore.Qt.AlignRight)
        self.errorLabel = QtWidgets.QLabel(currencyWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.errorLabel.sizePolicy().hasHeightForWidth())
        self.errorLabel.setSizePolicy(sizePolicy)
        self.errorLabel.setStyleSheet("color: red")
        self.errorLabel.setText("")
        self.errorLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.errorLabel.setObjectName("errorLabel")
        self.verticalLayout.addWidget(self.errorLabel)
        self.scrollArea = QtWidgets.QScrollArea(currencyWidget)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, -376, 714, 1019))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.currencyGroupBox = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.currencyGroupBox.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.currencyGroupBox.setObjectName("currencyGroupBox")
        self.formLayout_2 = QtWidgets.QFormLayout(self.currencyGroupBox)
        self.formLayout_2.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout_2.setObjectName("formLayout_2")
        self.nameLabel = QtWidgets.QLabel(self.currencyGroupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.nameLabel.setFont(font)
        self.nameLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.nameLabel.setObjectName("nameLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.nameLabel)
        self.nameValueLabel = QtWidgets.QLabel(self.currencyGroupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.nameValueLabel.setFont(font)
        self.nameValueLabel.setText("")
        self.nameValueLabel.setObjectName("nameValueLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.nameValueLabel)
        self.symbolLabel = QtWidgets.QLabel(self.currencyGroupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.symbolLabel.setFont(font)
        self.symbolLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.symbolLabel.setObjectName("symbolLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.symbolLabel)
        self.symbolValueLabel = QtWidgets.QLabel(self.currencyGroupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.symbolValueLabel.setFont(font)
        self.symbolValueLabel.setText("")
        self.symbolValueLabel.setObjectName("symbolValueLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.symbolValueLabel)
        self.universalDividendLabel = QtWidgets.QLabel(self.currencyGroupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.universalDividendLabel.setFont(font)
        self.universalDividendLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.universalDividendLabel.setObjectName("universalDividendLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.universalDividendLabel)
        self.universalDividendValueLabel = QtWidgets.QLabel(self.currencyGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.universalDividendValueLabel.sizePolicy().hasHeightForWidth())
        self.universalDividendValueLabel.setSizePolicy(sizePolicy)
        self.universalDividendValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.universalDividendValueLabel.setObjectName("universalDividendValueLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.universalDividendValueLabel)
        self.monetaryMassLabel = QtWidgets.QLabel(self.currencyGroupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.monetaryMassLabel.setFont(font)
        self.monetaryMassLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.monetaryMassLabel.setObjectName("monetaryMassLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.monetaryMassLabel)
        self.monetaryMassValueLabel = QtWidgets.QLabel(self.currencyGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.monetaryMassValueLabel.sizePolicy().hasHeightForWidth())
        self.monetaryMassValueLabel.setSizePolicy(sizePolicy)
        self.monetaryMassValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.monetaryMassValueLabel.setObjectName("monetaryMassValueLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.monetaryMassValueLabel)
        self.membersLabel = QtWidgets.QLabel(self.currencyGroupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.membersLabel.setFont(font)
        self.membersLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.membersLabel.setObjectName("membersLabel")
        self.formLayout_2.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.membersLabel)
        self.membersValueLabel = QtWidgets.QLabel(self.currencyGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.membersValueLabel.sizePolicy().hasHeightForWidth())
        self.membersValueLabel.setSizePolicy(sizePolicy)
        self.membersValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.membersValueLabel.setObjectName("membersValueLabel")
        self.formLayout_2.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.membersValueLabel)
        self.verticalLayout_3.addWidget(self.currencyGroupBox)
        self.blockchainGroupBox = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.blockchainGroupBox.setObjectName("blockchainGroupBox")
        self.formLayout_3 = QtWidgets.QFormLayout(self.blockchainGroupBox)
        self.formLayout_3.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout_3.setObjectName("formLayout_3")
        self.expectedBlockDurationLabel = QtWidgets.QLabel(self.blockchainGroupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.expectedBlockDurationLabel.setFont(font)
        self.expectedBlockDurationLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.expectedBlockDurationLabel.setObjectName("expectedBlockDurationLabel")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.expectedBlockDurationLabel)
        self.expectedBlockDurationValueLabel = QtWidgets.QLabel(self.blockchainGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.expectedBlockDurationValueLabel.sizePolicy().hasHeightForWidth())
        self.expectedBlockDurationValueLabel.setSizePolicy(sizePolicy)
        self.expectedBlockDurationValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.expectedBlockDurationValueLabel.setObjectName("expectedBlockDurationValueLabel")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.expectedBlockDurationValueLabel)
        self.expectedEpochDurationLabel = QtWidgets.QLabel(self.blockchainGroupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.expectedEpochDurationLabel.setFont(font)
        self.expectedEpochDurationLabel.setObjectName("expectedEpochDurationLabel")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.expectedEpochDurationLabel)
        self.expectedEpochDurationValueLabel = QtWidgets.QLabel(self.blockchainGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.expectedEpochDurationValueLabel.sizePolicy().hasHeightForWidth())
        self.expectedEpochDurationValueLabel.setSizePolicy(sizePolicy)
        self.expectedEpochDurationValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.expectedEpochDurationValueLabel.setObjectName("expectedEpochDurationValueLabel")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.expectedEpochDurationValueLabel)
        self.verticalLayout_3.addWidget(self.blockchainGroupBox)
        self.WOTGroupBox = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.WOTGroupBox.setObjectName("WOTGroupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.WOTGroupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.identityGroupBox = QtWidgets.QGroupBox(self.WOTGroupBox)
        self.identityGroupBox.setObjectName("identityGroupBox")
        self.formLayout_5 = QtWidgets.QFormLayout(self.identityGroupBox)
        self.formLayout_5.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout_5.setFormAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.formLayout_5.setObjectName("formLayout_5")
        self.automaticRevocationPeriodLabel = QtWidgets.QLabel(self.identityGroupBox)
        self.automaticRevocationPeriodLabel.setObjectName("automaticRevocationPeriodLabel")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.automaticRevocationPeriodLabel)
        self.automaticRevocationPeriodValueLabel = QtWidgets.QLabel(self.identityGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.automaticRevocationPeriodValueLabel.sizePolicy().hasHeightForWidth())
        self.automaticRevocationPeriodValueLabel.setSizePolicy(sizePolicy)
        self.automaticRevocationPeriodValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.automaticRevocationPeriodValueLabel.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.automaticRevocationPeriodValueLabel.setObjectName("automaticRevocationPeriodValueLabel")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.automaticRevocationPeriodValueLabel)
        self.minimumDelayBetweenChangingIdentityOwnerAccountLabel = QtWidgets.QLabel(self.identityGroupBox)
        self.minimumDelayBetweenChangingIdentityOwnerAccountLabel.setObjectName("minimumDelayBetweenChangingIdentityOwnerAccountLabel")
        self.formLayout_5.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.minimumDelayBetweenChangingIdentityOwnerAccountLabel)
        self.minimumDelayBetweenChangingIdentityOwnerAccountValueLabel = QtWidgets.QLabel(self.identityGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.minimumDelayBetweenChangingIdentityOwnerAccountValueLabel.sizePolicy().hasHeightForWidth())
        self.minimumDelayBetweenChangingIdentityOwnerAccountValueLabel.setSizePolicy(sizePolicy)
        self.minimumDelayBetweenChangingIdentityOwnerAccountValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.minimumDelayBetweenChangingIdentityOwnerAccountValueLabel.setObjectName("minimumDelayBetweenChangingIdentityOwnerAccountValueLabel")
        self.formLayout_5.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.minimumDelayBetweenChangingIdentityOwnerAccountValueLabel)
        self.confirmIdentityPeriodLabel = QtWidgets.QLabel(self.identityGroupBox)
        self.confirmIdentityPeriodLabel.setObjectName("confirmIdentityPeriodLabel")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.confirmIdentityPeriodLabel)
        self.confirmIdentityPeriodValueLabel = QtWidgets.QLabel(self.identityGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.confirmIdentityPeriodValueLabel.sizePolicy().hasHeightForWidth())
        self.confirmIdentityPeriodValueLabel.setSizePolicy(sizePolicy)
        self.confirmIdentityPeriodValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.confirmIdentityPeriodValueLabel.setObjectName("confirmIdentityPeriodValueLabel")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.confirmIdentityPeriodValueLabel)
        self.identityValidationPeriodLabel = QtWidgets.QLabel(self.identityGroupBox)
        self.identityValidationPeriodLabel.setObjectName("identityValidationPeriodLabel")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.identityValidationPeriodLabel)
        self.identityValidationPeriodValueLabel = QtWidgets.QLabel(self.identityGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.identityValidationPeriodValueLabel.sizePolicy().hasHeightForWidth())
        self.identityValidationPeriodValueLabel.setSizePolicy(sizePolicy)
        self.identityValidationPeriodValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.identityValidationPeriodValueLabel.setObjectName("identityValidationPeriodValueLabel")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.identityValidationPeriodValueLabel)
        self.identityDeletionAfterRevocationLabel = QtWidgets.QLabel(self.identityGroupBox)
        self.identityDeletionAfterRevocationLabel.setObjectName("identityDeletionAfterRevocationLabel")
        self.formLayout_5.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.identityDeletionAfterRevocationLabel)
        self.identityDeletionAfterRevocationValueLabel = QtWidgets.QLabel(self.identityGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.identityDeletionAfterRevocationValueLabel.sizePolicy().hasHeightForWidth())
        self.identityDeletionAfterRevocationValueLabel.setSizePolicy(sizePolicy)
        self.identityDeletionAfterRevocationValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.identityDeletionAfterRevocationValueLabel.setObjectName("identityDeletionAfterRevocationValueLabel")
        self.formLayout_5.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.identityDeletionAfterRevocationValueLabel)
        self.minimumDelayBetweenIdentityCreationLabel = QtWidgets.QLabel(self.identityGroupBox)
        self.minimumDelayBetweenIdentityCreationLabel.setObjectName("minimumDelayBetweenIdentityCreationLabel")
        self.formLayout_5.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.minimumDelayBetweenIdentityCreationLabel)
        self.minimumDelayBetweenIdentityCreationValueLabel = QtWidgets.QLabel(self.identityGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.minimumDelayBetweenIdentityCreationValueLabel.sizePolicy().hasHeightForWidth())
        self.minimumDelayBetweenIdentityCreationValueLabel.setSizePolicy(sizePolicy)
        self.minimumDelayBetweenIdentityCreationValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.minimumDelayBetweenIdentityCreationValueLabel.setObjectName("minimumDelayBetweenIdentityCreationValueLabel")
        self.formLayout_5.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.minimumDelayBetweenIdentityCreationValueLabel)
        self.verticalLayout_2.addWidget(self.identityGroupBox)
        self.certificationGroupBox = QtWidgets.QGroupBox(self.WOTGroupBox)
        self.certificationGroupBox.setObjectName("certificationGroupBox")
        self.formLayout_4 = QtWidgets.QFormLayout(self.certificationGroupBox)
        self.formLayout_4.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout_4.setObjectName("formLayout_4")
        self.certificationNumberToBeMemberLabel = QtWidgets.QLabel(self.certificationGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.certificationNumberToBeMemberLabel.sizePolicy().hasHeightForWidth())
        self.certificationNumberToBeMemberLabel.setSizePolicy(sizePolicy)
        self.certificationNumberToBeMemberLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.certificationNumberToBeMemberLabel.setObjectName("certificationNumberToBeMemberLabel")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.certificationNumberToBeMemberLabel)
        self.certificationNumberToBeMemberValueLabel = QtWidgets.QLabel(self.certificationGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.certificationNumberToBeMemberValueLabel.sizePolicy().hasHeightForWidth())
        self.certificationNumberToBeMemberValueLabel.setSizePolicy(sizePolicy)
        self.certificationNumberToBeMemberValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.certificationNumberToBeMemberValueLabel.setObjectName("certificationNumberToBeMemberValueLabel")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.certificationNumberToBeMemberValueLabel)
        self.minimumCertificationsReceivedToBeCertifierLabel = QtWidgets.QLabel(self.certificationGroupBox)
        self.minimumCertificationsReceivedToBeCertifierLabel.setObjectName("minimumCertificationsReceivedToBeCertifierLabel")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.minimumCertificationsReceivedToBeCertifierLabel)
        self.minimumCertificationsReceivedToBeCertifierValueLabel = QtWidgets.QLabel(self.certificationGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.minimumCertificationsReceivedToBeCertifierValueLabel.sizePolicy().hasHeightForWidth())
        self.minimumCertificationsReceivedToBeCertifierValueLabel.setSizePolicy(sizePolicy)
        self.minimumCertificationsReceivedToBeCertifierValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.minimumCertificationsReceivedToBeCertifierValueLabel.setObjectName("minimumCertificationsReceivedToBeCertifierValueLabel")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.minimumCertificationsReceivedToBeCertifierValueLabel)
        self.maximumNumberOfCertificationPerMemberLabel = QtWidgets.QLabel(self.certificationGroupBox)
        self.maximumNumberOfCertificationPerMemberLabel.setObjectName("maximumNumberOfCertificationPerMemberLabel")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.maximumNumberOfCertificationPerMemberLabel)
        self.maximumNumberOfCertificationPerMemberValueLabel = QtWidgets.QLabel(self.certificationGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.maximumNumberOfCertificationPerMemberValueLabel.sizePolicy().hasHeightForWidth())
        self.maximumNumberOfCertificationPerMemberValueLabel.setSizePolicy(sizePolicy)
        self.maximumNumberOfCertificationPerMemberValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.maximumNumberOfCertificationPerMemberValueLabel.setObjectName("maximumNumberOfCertificationPerMemberValueLabel")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.maximumNumberOfCertificationPerMemberValueLabel)
        self.minimumDelayBetweenTwoCertificationsLabel = QtWidgets.QLabel(self.certificationGroupBox)
        self.minimumDelayBetweenTwoCertificationsLabel.setObjectName("minimumDelayBetweenTwoCertificationsLabel")
        self.formLayout_4.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.minimumDelayBetweenTwoCertificationsLabel)
        self.validityPeriodOfCertificationLabel = QtWidgets.QLabel(self.certificationGroupBox)
        self.validityPeriodOfCertificationLabel.setObjectName("validityPeriodOfCertificationLabel")
        self.formLayout_4.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.validityPeriodOfCertificationLabel)
        self.validityPeriodOfCertificationValueLabel = QtWidgets.QLabel(self.certificationGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.validityPeriodOfCertificationValueLabel.sizePolicy().hasHeightForWidth())
        self.validityPeriodOfCertificationValueLabel.setSizePolicy(sizePolicy)
        self.validityPeriodOfCertificationValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.validityPeriodOfCertificationValueLabel.setObjectName("validityPeriodOfCertificationValueLabel")
        self.formLayout_4.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.validityPeriodOfCertificationValueLabel)
        self.minimumDelayBetweenTwoCertificationsValueLabel = QtWidgets.QLabel(self.certificationGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.minimumDelayBetweenTwoCertificationsValueLabel.sizePolicy().hasHeightForWidth())
        self.minimumDelayBetweenTwoCertificationsValueLabel.setSizePolicy(sizePolicy)
        self.minimumDelayBetweenTwoCertificationsValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.minimumDelayBetweenTwoCertificationsValueLabel.setObjectName("minimumDelayBetweenTwoCertificationsValueLabel")
        self.formLayout_4.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.minimumDelayBetweenTwoCertificationsValueLabel)
        self.verticalLayout_2.addWidget(self.certificationGroupBox)
        self.membershipGroupBox = QtWidgets.QGroupBox(self.WOTGroupBox)
        self.membershipGroupBox.setObjectName("membershipGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.membershipGroupBox)
        self.formLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout.setObjectName("formLayout")
        self.minimumDelayBetweenTwoMembershipRenewalsLabel = QtWidgets.QLabel(self.membershipGroupBox)
        self.minimumDelayBetweenTwoMembershipRenewalsLabel.setObjectName("minimumDelayBetweenTwoMembershipRenewalsLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.minimumDelayBetweenTwoMembershipRenewalsLabel)
        self.minimumDelayBetweenTwoMembershipRenewalsValueLabel = QtWidgets.QLabel(self.membershipGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.minimumDelayBetweenTwoMembershipRenewalsValueLabel.sizePolicy().hasHeightForWidth())
        self.minimumDelayBetweenTwoMembershipRenewalsValueLabel.setSizePolicy(sizePolicy)
        self.minimumDelayBetweenTwoMembershipRenewalsValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.minimumDelayBetweenTwoMembershipRenewalsValueLabel.setObjectName("minimumDelayBetweenTwoMembershipRenewalsValueLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.minimumDelayBetweenTwoMembershipRenewalsValueLabel)
        self.membershipValidityPeriodLabel = QtWidgets.QLabel(self.membershipGroupBox)
        self.membershipValidityPeriodLabel.setObjectName("membershipValidityPeriodLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.membershipValidityPeriodLabel)
        self.membershipValidityPeriodValueLabel = QtWidgets.QLabel(self.membershipGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.membershipValidityPeriodValueLabel.sizePolicy().hasHeightForWidth())
        self.membershipValidityPeriodValueLabel.setSizePolicy(sizePolicy)
        self.membershipValidityPeriodValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.membershipValidityPeriodValueLabel.setObjectName("membershipValidityPeriodValueLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.membershipValidityPeriodValueLabel)
        self.maximumDistanceInStepLabel = QtWidgets.QLabel(self.membershipGroupBox)
        self.maximumDistanceInStepLabel.setObjectName("maximumDistanceInStepLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.maximumDistanceInStepLabel)
        self.maximumDistanceInStepValueLabel = QtWidgets.QLabel(self.membershipGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.maximumDistanceInStepValueLabel.sizePolicy().hasHeightForWidth())
        self.maximumDistanceInStepValueLabel.setSizePolicy(sizePolicy)
        self.maximumDistanceInStepValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.maximumDistanceInStepValueLabel.setObjectName("maximumDistanceInStepValueLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.maximumDistanceInStepValueLabel)
        self.minimumPercentageOfRemoteReferralMembersToBeMemberLabel = QtWidgets.QLabel(self.membershipGroupBox)
        self.minimumPercentageOfRemoteReferralMembersToBeMemberLabel.setObjectName("minimumPercentageOfRemoteReferralMembersToBeMemberLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.minimumPercentageOfRemoteReferralMembersToBeMemberLabel)
        self.minimumPercentageOfRemoteReferralMembersToBeMemberValueLabel = QtWidgets.QLabel(self.membershipGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.minimumPercentageOfRemoteReferralMembersToBeMemberValueLabel.sizePolicy().hasHeightForWidth())
        self.minimumPercentageOfRemoteReferralMembersToBeMemberValueLabel.setSizePolicy(sizePolicy)
        self.minimumPercentageOfRemoteReferralMembersToBeMemberValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.minimumPercentageOfRemoteReferralMembersToBeMemberValueLabel.setObjectName("minimumPercentageOfRemoteReferralMembersToBeMemberValueLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.minimumPercentageOfRemoteReferralMembersToBeMemberValueLabel)
        self.verticalLayout_2.addWidget(self.membershipGroupBox)
        self.smithGroupBox = QtWidgets.QGroupBox(self.WOTGroupBox)
        self.smithGroupBox.setObjectName("smithGroupBox")
        self.formLayout_6 = QtWidgets.QFormLayout(self.smithGroupBox)
        self.formLayout_6.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout_6.setObjectName("formLayout_6")
        self.maximumCertificationsPerSmithLabel = QtWidgets.QLabel(self.smithGroupBox)
        self.maximumCertificationsPerSmithLabel.setObjectName("maximumCertificationsPerSmithLabel")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.maximumCertificationsPerSmithLabel)
        self.maximumCertificationsPerSmithValueLabel = QtWidgets.QLabel(self.smithGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.maximumCertificationsPerSmithValueLabel.sizePolicy().hasHeightForWidth())
        self.maximumCertificationsPerSmithValueLabel.setSizePolicy(sizePolicy)
        self.maximumCertificationsPerSmithValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.maximumCertificationsPerSmithValueLabel.setObjectName("maximumCertificationsPerSmithValueLabel")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.maximumCertificationsPerSmithValueLabel)
        self.numberOfCertificationsToBecomeSmithLabel = QtWidgets.QLabel(self.smithGroupBox)
        self.numberOfCertificationsToBecomeSmithLabel.setObjectName("numberOfCertificationsToBecomeSmithLabel")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.numberOfCertificationsToBecomeSmithLabel)
        self.numberOfCertificationsToBecomeSmithValueLabel = QtWidgets.QLabel(self.smithGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.numberOfCertificationsToBecomeSmithValueLabel.sizePolicy().hasHeightForWidth())
        self.numberOfCertificationsToBecomeSmithValueLabel.setSizePolicy(sizePolicy)
        self.numberOfCertificationsToBecomeSmithValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.numberOfCertificationsToBecomeSmithValueLabel.setObjectName("numberOfCertificationsToBecomeSmithValueLabel")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.numberOfCertificationsToBecomeSmithValueLabel)
        self.maximumInactivityDurationAllowedForSmithLabel = QtWidgets.QLabel(self.smithGroupBox)
        self.maximumInactivityDurationAllowedForSmithLabel.setObjectName("maximumInactivityDurationAllowedForSmithLabel")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.maximumInactivityDurationAllowedForSmithLabel)
        self.maximumInactivityDurationAllowedForSmithValueLabel = QtWidgets.QLabel(self.smithGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.maximumInactivityDurationAllowedForSmithValueLabel.sizePolicy().hasHeightForWidth())
        self.maximumInactivityDurationAllowedForSmithValueLabel.setSizePolicy(sizePolicy)
        self.maximumInactivityDurationAllowedForSmithValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);\n"
"\n"
"\n"
"")
        self.maximumInactivityDurationAllowedForSmithValueLabel.setObjectName("maximumInactivityDurationAllowedForSmithValueLabel")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.maximumInactivityDurationAllowedForSmithValueLabel)
        self.verticalLayout_2.addWidget(self.smithGroupBox)
        self.verticalLayout_3.addWidget(self.WOTGroupBox)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout.addWidget(self.scrollArea)

        self.retranslateUi(currencyWidget)
        QtCore.QMetaObject.connectSlotsByName(currencyWidget)

    def retranslateUi(self, currencyWidget):
        #  _translate = QtCore.QCoreApplication.translate
        currencyWidget.setWindowTitle(_("Currency parameters"))
        self.refreshButton.setText(_("Refresh"))
        self.currencyGroupBox.setTitle(_("Currency"))
        self.nameLabel.setText(_("Name"))
        self.symbolLabel.setText(_("Symbol"))
        self.universalDividendLabel.setText(_("Universal Dividend"))
        self.universalDividendValueLabel.setText(_("?"))
        self.monetaryMassLabel.setText(_("Monetary Mass"))
        self.monetaryMassValueLabel.setText(_("?"))
        self.membersLabel.setText(_("Members"))
        self.membersValueLabel.setText(_("?"))
        self.blockchainGroupBox.setTitle(_("Blockchain"))
        self.expectedBlockDurationLabel.setText(_("Expected Block duration"))
        self.expectedBlockDurationValueLabel.setText(_("?"))
        self.expectedEpochDurationLabel.setText(_("Expected Epoch duration"))
        self.expectedEpochDurationValueLabel.setText(_("?"))
        self.WOTGroupBox.setTitle(_("Web of Trust"))
        self.identityGroupBox.setTitle(_("Identity"))
        self.automaticRevocationPeriodLabel.setText(_("Automatic revocation period after losing membership"))
        self.automaticRevocationPeriodValueLabel.setText(_("?"))
        self.minimumDelayBetweenChangingIdentityOwnerAccountLabel.setText(_("Minimum delay between changing identity owner account"))
        self.minimumDelayBetweenChangingIdentityOwnerAccountValueLabel.setText(_("?"))
        self.confirmIdentityPeriodLabel.setText(_("Confirm identity period"))
        self.confirmIdentityPeriodValueLabel.setText(_("?"))
        self.identityValidationPeriodLabel.setText(_("Identity validation period"))
        self.identityValidationPeriodValueLabel.setText(_("?"))
        self.identityDeletionAfterRevocationLabel.setText(_("Identity deletion after revocation period"))
        self.identityDeletionAfterRevocationValueLabel.setText(_("?"))
        self.minimumDelayBetweenIdentityCreationLabel.setText(_("Minimum delay between Identity creation"))
        self.minimumDelayBetweenIdentityCreationValueLabel.setText(_("?"))
        self.certificationGroupBox.setTitle(_("Certification"))
        self.certificationNumberToBeMemberLabel.setText(_("Number of certifications to become a member"))
        self.certificationNumberToBeMemberValueLabel.setText(_("?"))
        self.minimumCertificationsReceivedToBeCertifierLabel.setText(_("Minimum certifications received to be a certifier"))
        self.minimumCertificationsReceivedToBeCertifierValueLabel.setText(_("?"))
        self.maximumNumberOfCertificationPerMemberLabel.setText(_("Maximum number of certifications issued per member"))
        self.maximumNumberOfCertificationPerMemberValueLabel.setText(_("?"))
        self.minimumDelayBetweenTwoCertificationsLabel.setText(_("Minimum delay between certifications"))
        self.validityPeriodOfCertificationLabel.setText(_("Validity period of a certification"))
        self.validityPeriodOfCertificationValueLabel.setText(_("?"))
        self.minimumDelayBetweenTwoCertificationsValueLabel.setText(_("?"))
        self.membershipGroupBox.setTitle(_("Membership"))
        self.minimumDelayBetweenTwoMembershipRenewalsLabel.setText(_("Minimum delay between two membership renewals"))
        self.minimumDelayBetweenTwoMembershipRenewalsValueLabel.setText(_("?"))
        self.membershipValidityPeriodLabel.setText(_("Membership validity period"))
        self.membershipValidityPeriodValueLabel.setText(_("?"))
        self.maximumDistanceInStepLabel.setText(_("Maximum distance, through certifications, between an identity and referring members"))
        self.maximumDistanceInStepValueLabel.setText(_("?"))
        self.minimumPercentageOfRemoteReferralMembersToBeMemberLabel.setText(_("Minimum percentage of remote referral members for membership"))
        self.minimumPercentageOfRemoteReferralMembersToBeMemberValueLabel.setText(_("?"))
        self.smithGroupBox.setTitle(_("Smith"))
        self.maximumCertificationsPerSmithLabel.setText(_("Maximum number of certification issued per smith"))
        self.maximumCertificationsPerSmithValueLabel.setText(_("?"))
        self.numberOfCertificationsToBecomeSmithLabel.setText(_("Number of certifications to become a smith"))
        self.numberOfCertificationsToBecomeSmithValueLabel.setText(_("?"))
        self.maximumInactivityDurationAllowedForSmithLabel.setText(_("Maximum inactivity duration allowed to stay smith"))
        self.maximumInactivityDurationAllowedForSmithValueLabel.setText(_("?"))
import tikka.slots.pyqt.resources.icons.index_rc
