# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/widgets/account_transfer_row.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_AccountTransferRowWidget(object):
    def setupUi(self, AccountTransferRowWidget):
        AccountTransferRowWidget.setObjectName("AccountTransferRowWidget")
        AccountTransferRowWidget.resize(838, 73)
        self.verticalLayout = QtWidgets.QVBoxLayout(AccountTransferRowWidget)
        self.verticalLayout.setContentsMargins(-1, 0, -1, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.gridLayout.setVerticalSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(6)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.amountValueLabel = QtWidgets.QLabel(AccountTransferRowWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.amountValueLabel.sizePolicy().hasHeightForWidth())
        self.amountValueLabel.setSizePolicy(sizePolicy)
        self.amountValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid #73AD21;\n"
"border-radius: 10%;\n"
"background: #73AD21;\n"
"\n"
"\n"
"")
        self.amountValueLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.amountValueLabel.setObjectName("amountValueLabel")
        self.horizontalLayout.addWidget(self.amountValueLabel)
        self.gridLayout.addLayout(self.horizontalLayout, 0, 4, 1, 1)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.accountAddressValuelabel = QtWidgets.QLabel(AccountTransferRowWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.accountAddressValuelabel.sizePolicy().hasHeightForWidth())
        self.accountAddressValuelabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Courier")
        self.accountAddressValuelabel.setFont(font)
        self.accountAddressValuelabel.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.accountAddressValuelabel.setObjectName("accountAddressValuelabel")
        self.verticalLayout_2.addWidget(self.accountAddressValuelabel)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.identityNameValueLabel = QtWidgets.QLabel(AccountTransferRowWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.identityNameValueLabel.sizePolicy().hasHeightForWidth())
        self.identityNameValueLabel.setSizePolicy(sizePolicy)
        self.identityNameValueLabel.setObjectName("identityNameValueLabel")
        self.horizontalLayout_2.addWidget(self.identityNameValueLabel)
        self.accountNameValueLabel = QtWidgets.QLabel(AccountTransferRowWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.accountNameValueLabel.sizePolicy().hasHeightForWidth())
        self.accountNameValueLabel.setSizePolicy(sizePolicy)
        self.accountNameValueLabel.setObjectName("accountNameValueLabel")
        self.horizontalLayout_2.addWidget(self.accountNameValueLabel)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.datetimeValueLabel = QtWidgets.QLabel(AccountTransferRowWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.datetimeValueLabel.sizePolicy().hasHeightForWidth())
        self.datetimeValueLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setItalic(True)
        self.datetimeValueLabel.setFont(font)
        self.datetimeValueLabel.setStyleSheet("color: \"gray\"")
        self.datetimeValueLabel.setObjectName("datetimeValueLabel")
        self.verticalLayout_2.addWidget(self.datetimeValueLabel)
        self.gridLayout.addLayout(self.verticalLayout_2, 0, 0, 1, 1)
        self.commentValueLabel = QtWidgets.QLabel(AccountTransferRowWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.commentValueLabel.sizePolicy().hasHeightForWidth())
        self.commentValueLabel.setSizePolicy(sizePolicy)
        self.commentValueLabel.setAlignment(QtCore.Qt.AlignHCenter|QtCore.Qt.AlignTop)
        self.commentValueLabel.setWordWrap(True)
        self.commentValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByMouse)
        self.commentValueLabel.setObjectName("commentValueLabel")
        self.gridLayout.addWidget(self.commentValueLabel, 0, 2, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout)
        self.line = QtWidgets.QFrame(AccountTransferRowWidget)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setLineWidth(1)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setObjectName("line")
        self.verticalLayout.addWidget(self.line)

        self.retranslateUi(AccountTransferRowWidget)
        QtCore.QMetaObject.connectSlotsByName(AccountTransferRowWidget)

    def retranslateUi(self, AccountTransferRowWidget):
        #  _translate = QtCore.QCoreApplication.translate
        AccountTransferRowWidget.setWindowTitle(_("TransferWidget"))
        self.amountValueLabel.setText(_("0"))
        self.accountAddressValuelabel.setText(_("address"))
        self.identityNameValueLabel.setText(_("name#0000"))
        self.accountNameValueLabel.setText(_(" - Name"))
        self.datetimeValueLabel.setText(_("datetime"))
        self.commentValueLabel.setText(_("0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 "))
