# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/windows/v1_account_import.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_V1AccountImportDialog(object):
    def setupUi(self, V1AccountImportDialog):
        V1AccountImportDialog.setObjectName("V1AccountImportDialog")
        V1AccountImportDialog.resize(793, 456)
        self.verticalLayout = QtWidgets.QVBoxLayout(V1AccountImportDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.imagelabel = QtWidgets.QLabel(V1AccountImportDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.imagelabel.sizePolicy().hasHeightForWidth())
        self.imagelabel.setSizePolicy(sizePolicy)
        self.imagelabel.setMinimumSize(QtCore.QSize(0, 0))
        self.imagelabel.setMaximumSize(QtCore.QSize(200, 200))
        self.imagelabel.setSizeIncrement(QtCore.QSize(0, 0))
        self.imagelabel.setBaseSize(QtCore.QSize(0, 0))
        self.imagelabel.setText("")
        self.imagelabel.setPixmap(QtGui.QPixmap(":/images/safe_background"))
        self.imagelabel.setScaledContents(True)
        self.imagelabel.setAlignment(QtCore.Qt.AlignCenter)
        self.imagelabel.setObjectName("imagelabel")
        self.verticalLayout.addWidget(self.imagelabel, 0, QtCore.Qt.AlignHCenter)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.v1AddressLabel = QtWidgets.QLabel(V1AccountImportDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.v1AddressLabel.sizePolicy().hasHeightForWidth())
        self.v1AddressLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.v1AddressLabel.setFont(font)
        self.v1AddressLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.v1AddressLabel.setObjectName("v1AddressLabel")
        self.gridLayout.addWidget(self.v1AddressLabel, 2, 0, 1, 1)
        self.nameLineEdit = QtWidgets.QLineEdit(V1AccountImportDialog)
        self.nameLineEdit.setObjectName("nameLineEdit")
        self.gridLayout.addWidget(self.nameLineEdit, 4, 2, 1, 1)
        self.addressValueLabel = QtWidgets.QLabel(V1AccountImportDialog)
        self.addressValueLabel.setText("")
        self.addressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.addressValueLabel.setObjectName("addressValueLabel")
        self.gridLayout.addWidget(self.addressValueLabel, 3, 2, 1, 1)
        self.secretIDLabel = QtWidgets.QLabel(V1AccountImportDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.secretIDLabel.sizePolicy().hasHeightForWidth())
        self.secretIDLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.secretIDLabel.setFont(font)
        self.secretIDLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.secretIDLabel.setObjectName("secretIDLabel")
        self.gridLayout.addWidget(self.secretIDLabel, 0, 0, 1, 1)
        self.passwordIDLabel = QtWidgets.QLabel(V1AccountImportDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.passwordIDLabel.setFont(font)
        self.passwordIDLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.passwordIDLabel.setObjectName("passwordIDLabel")
        self.gridLayout.addWidget(self.passwordIDLabel, 1, 0, 1, 1)
        self.nameLabel = QtWidgets.QLabel(V1AccountImportDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.nameLabel.setFont(font)
        self.nameLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.nameLabel.setObjectName("nameLabel")
        self.gridLayout.addWidget(self.nameLabel, 4, 0, 1, 1)
        self.v1AddressValueLabel = QtWidgets.QLabel(V1AccountImportDialog)
        self.v1AddressValueLabel.setText("")
        self.v1AddressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.v1AddressValueLabel.setObjectName("v1AddressValueLabel")
        self.gridLayout.addWidget(self.v1AddressValueLabel, 2, 2, 1, 1)
        self.secretIDLineEdit = QtWidgets.QLineEdit(V1AccountImportDialog)
        self.secretIDLineEdit.setEchoMode(QtWidgets.QLineEdit.Password)
        self.secretIDLineEdit.setReadOnly(False)
        self.secretIDLineEdit.setObjectName("secretIDLineEdit")
        self.gridLayout.addWidget(self.secretIDLineEdit, 0, 2, 1, 1)
        self.addressLabel = QtWidgets.QLabel(V1AccountImportDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.addressLabel.setFont(font)
        self.addressLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.addressLabel.setObjectName("addressLabel")
        self.gridLayout.addWidget(self.addressLabel, 3, 0, 1, 1)
        self.passwordIDLineEdit = QtWidgets.QLineEdit(V1AccountImportDialog)
        self.passwordIDLineEdit.setEchoMode(QtWidgets.QLineEdit.Password)
        self.passwordIDLineEdit.setObjectName("passwordIDLineEdit")
        self.gridLayout.addWidget(self.passwordIDLineEdit, 1, 2, 1, 1)
        self.showButton = QtWidgets.QPushButton(V1AccountImportDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.showButton.sizePolicy().hasHeightForWidth())
        self.showButton.setSizePolicy(sizePolicy)
        self.showButton.setObjectName("showButton")
        self.gridLayout.addWidget(self.showButton, 0, 3, 1, 1, QtCore.Qt.AlignRight)
        self.verticalLayout.addLayout(self.gridLayout)
        self.errorLabel = QtWidgets.QLabel(V1AccountImportDialog)
        self.errorLabel.setStyleSheet("color: red")
        self.errorLabel.setText("")
        self.errorLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.errorLabel.setObjectName("errorLabel")
        self.verticalLayout.addWidget(self.errorLabel)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.passwordLabel = QtWidgets.QLabel(V1AccountImportDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.passwordLabel.sizePolicy().hasHeightForWidth())
        self.passwordLabel.setSizePolicy(sizePolicy)
        self.passwordLabel.setSizeIncrement(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.passwordLabel.setFont(font)
        self.passwordLabel.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.passwordLabel.setObjectName("passwordLabel")
        self.horizontalLayout.addWidget(self.passwordLabel)
        self.passwordLineEdit = QtWidgets.QLineEdit(V1AccountImportDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.passwordLineEdit.sizePolicy().hasHeightForWidth())
        self.passwordLineEdit.setSizePolicy(sizePolicy)
        self.passwordLineEdit.setMaxLength(20)
        self.passwordLineEdit.setAlignment(QtCore.Qt.AlignCenter)
        self.passwordLineEdit.setReadOnly(True)
        self.passwordLineEdit.setObjectName("passwordLineEdit")
        self.horizontalLayout.addWidget(self.passwordLineEdit)
        self.passwordChangeButton = QtWidgets.QPushButton(V1AccountImportDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.passwordChangeButton.sizePolicy().hasHeightForWidth())
        self.passwordChangeButton.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/refresh_icon"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.passwordChangeButton.setIcon(icon)
        self.passwordChangeButton.setObjectName("passwordChangeButton")
        self.horizontalLayout.addWidget(self.passwordChangeButton)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.buttonBox = QtWidgets.QDialogButtonBox(V1AccountImportDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox, 0, QtCore.Qt.AlignHCenter)

        self.retranslateUi(V1AccountImportDialog)
        self.buttonBox.accepted.connect(V1AccountImportDialog.accept) # type: ignore
        self.buttonBox.rejected.connect(V1AccountImportDialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(V1AccountImportDialog)
        V1AccountImportDialog.setTabOrder(self.secretIDLineEdit, self.passwordIDLineEdit)
        V1AccountImportDialog.setTabOrder(self.passwordIDLineEdit, self.nameLineEdit)
        V1AccountImportDialog.setTabOrder(self.nameLineEdit, self.passwordLineEdit)
        V1AccountImportDialog.setTabOrder(self.passwordLineEdit, self.passwordChangeButton)
        V1AccountImportDialog.setTabOrder(self.passwordChangeButton, self.showButton)

    def retranslateUi(self, V1AccountImportDialog):
        #  _translate = QtCore.QCoreApplication.translate
        V1AccountImportDialog.setWindowTitle(_("Import account"))
        self.v1AddressLabel.setText(_("V1 address"))
        self.secretIDLabel.setText(_("Secret ID"))
        self.passwordIDLabel.setText(_("Password"))
        self.nameLabel.setText(_("Name"))
        self.addressLabel.setText(_("Address"))
        self.showButton.setText(_("Show"))
        self.passwordLabel.setText(_("Password"))
        self.passwordChangeButton.setText(_("Change"))
import tikka.slots.pyqt.resources.icons.index_rc
