# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/windows/transfers_export.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_transfersExportDialog(object):
    def setupUi(self, transfersExportDialog):
        transfersExportDialog.setObjectName("transfersExportDialog")
        transfersExportDialog.resize(801, 457)
        self.formLayout = QtWidgets.QFormLayout(transfersExportDialog)
        self.formLayout.setObjectName("formLayout")
        self.fromLabel = QtWidgets.QLabel(transfersExportDialog)
        self.fromLabel.setObjectName("fromLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.fromLabel)
        self.fromCalendarWidget = QtWidgets.QCalendarWidget(transfersExportDialog)
        self.fromCalendarWidget.setObjectName("fromCalendarWidget")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.fromCalendarWidget)
        self.toLabel = QtWidgets.QLabel(transfersExportDialog)
        self.toLabel.setObjectName("toLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.toLabel)
        self.toCalendarWidget = QtWidgets.QCalendarWidget(transfersExportDialog)
        self.toCalendarWidget.setObjectName("toCalendarWidget")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.toCalendarWidget)
        self.buttonBox = QtWidgets.QDialogButtonBox(transfersExportDialog)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.buttonBox)
        self.todayButton = QtWidgets.QPushButton(transfersExportDialog)
        self.todayButton.setObjectName("todayButton")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.todayButton)

        self.retranslateUi(transfersExportDialog)
        QtCore.QMetaObject.connectSlotsByName(transfersExportDialog)

    def retranslateUi(self, transfersExportDialog):
        #  _translate = QtCore.QCoreApplication.translate
        transfersExportDialog.setWindowTitle(_("Export as"))
        self.fromLabel.setText(_("From"))
        self.toLabel.setText(_("To"))
        self.todayButton.setText(_("Today"))
