# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/windows/v1_account_import_wizard.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_importAccountV1Wizard(object):
    def setupUi(self, importAccountV1Wizard):
        importAccountV1Wizard.setObjectName("importAccountV1Wizard")
        importAccountV1Wizard.resize(780, 452)
        importAccountV1Wizard.setModal(True)
        self.wizardPage1 = QtWidgets.QWizardPage()
        self.wizardPage1.setObjectName("wizardPage1")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.wizardPage1)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.page1_label = QtWidgets.QLabel(self.wizardPage1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.page1_label.sizePolicy().hasHeightForWidth())
        self.page1_label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setStyleStrategy(QtGui.QFont.PreferAntialias)
        self.page1_label.setFont(font)
        self.page1_label.setWordWrap(True)
        self.page1_label.setObjectName("page1_label")
        self.verticalLayout_6.addWidget(self.page1_label)
        importAccountV1Wizard.addPage(self.wizardPage1)
        self.wizardPage2 = QtWidgets.QWizardPage()
        self.wizardPage2.setObjectName("wizardPage2")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.wizardPage2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.page2_label = QtWidgets.QLabel(self.wizardPage2)
        font = QtGui.QFont()
        font.setItalic(False)
        self.page2_label.setFont(font)
        self.page2_label.setAlignment(QtCore.Qt.AlignCenter)
        self.page2_label.setWordWrap(True)
        self.page2_label.setObjectName("page2_label")
        self.verticalLayout.addWidget(self.page2_label)
        self.groupBox = QtWidgets.QGroupBox(self.wizardPage2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.groupBox.setFont(font)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.gridLayout.setContentsMargins(0, 0, -1, 0)
        self.gridLayout.setHorizontalSpacing(6)
        self.gridLayout.setObjectName("gridLayout")
        self.sourceAddressValueLabel = QtWidgets.QLabel(self.groupBox)
        self.sourceAddressValueLabel.setText("")
        self.sourceAddressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.sourceAddressValueLabel.setObjectName("sourceAddressValueLabel")
        self.gridLayout.addWidget(self.sourceAddressValueLabel, 2, 2, 1, 1)
        self.sourceV1AddressLabel = QtWidgets.QLabel(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sourceV1AddressLabel.sizePolicy().hasHeightForWidth())
        self.sourceV1AddressLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sourceV1AddressLabel.setFont(font)
        self.sourceV1AddressLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sourceV1AddressLabel.setObjectName("sourceV1AddressLabel")
        self.gridLayout.addWidget(self.sourceV1AddressLabel, 1, 0, 1, 1)
        self.sourceAddressLabel = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sourceAddressLabel.setFont(font)
        self.sourceAddressLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sourceAddressLabel.setObjectName("sourceAddressLabel")
        self.gridLayout.addWidget(self.sourceAddressLabel, 2, 0, 1, 1)
        self.sourceBalanceValueLabel = QtWidgets.QLabel(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sourceBalanceValueLabel.sizePolicy().hasHeightForWidth())
        self.sourceBalanceValueLabel.setSizePolicy(sizePolicy)
        self.sourceBalanceValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);")
        self.sourceBalanceValueLabel.setObjectName("sourceBalanceValueLabel")
        self.gridLayout.addWidget(self.sourceBalanceValueLabel, 3, 2, 1, 1)
        self.sourceIdentityLabel = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sourceIdentityLabel.setFont(font)
        self.sourceIdentityLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sourceIdentityLabel.setObjectName("sourceIdentityLabel")
        self.gridLayout.addWidget(self.sourceIdentityLabel, 4, 0, 1, 1)
        self.sourceBalanceLabel = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sourceBalanceLabel.setFont(font)
        self.sourceBalanceLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sourceBalanceLabel.setObjectName("sourceBalanceLabel")
        self.gridLayout.addWidget(self.sourceBalanceLabel, 3, 0, 1, 1)
        self.sourceIdentityValueLabel = QtWidgets.QLabel(self.groupBox)
        self.sourceIdentityValueLabel.setText("")
        self.sourceIdentityValueLabel.setObjectName("sourceIdentityValueLabel")
        self.gridLayout.addWidget(self.sourceIdentityValueLabel, 4, 2, 1, 1)
        self.sourceV1AddressValueLabel = QtWidgets.QLabel(self.groupBox)
        self.sourceV1AddressValueLabel.setText("")
        self.sourceV1AddressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.sourceV1AddressValueLabel.setObjectName("sourceV1AddressValueLabel")
        self.gridLayout.addWidget(self.sourceV1AddressValueLabel, 1, 2, 1, 1)
        self.sourceV1AccountLabel = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sourceV1AccountLabel.setFont(font)
        self.sourceV1AccountLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sourceV1AccountLabel.setObjectName("sourceV1AccountLabel")
        self.gridLayout.addWidget(self.sourceV1AccountLabel, 0, 0, 1, 1)
        self.sourceV1AccountComboBox = QtWidgets.QComboBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sourceV1AccountComboBox.sizePolicy().hasHeightForWidth())
        self.sourceV1AccountComboBox.setSizePolicy(sizePolicy)
        self.sourceV1AccountComboBox.setObjectName("sourceV1AccountComboBox")
        self.gridLayout.addWidget(self.sourceV1AccountComboBox, 0, 2, 1, 1)
        self.verticalLayout_2.addLayout(self.gridLayout)
        self.sourceErrorLabel = QtWidgets.QLabel(self.groupBox)
        self.sourceErrorLabel.setText("")
        self.sourceErrorLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.sourceErrorLabel.setObjectName("sourceErrorLabel")
        self.verticalLayout_2.addWidget(self.sourceErrorLabel)
        self.verticalLayout.addWidget(self.groupBox)
        importAccountV1Wizard.addPage(self.wizardPage2)
        self.wizardPage3 = QtWidgets.QWizardPage()
        self.wizardPage3.setObjectName("wizardPage3")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.wizardPage3)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.page3_label = QtWidgets.QLabel(self.wizardPage3)
        font = QtGui.QFont()
        font.setItalic(False)
        self.page3_label.setFont(font)
        self.page3_label.setAlignment(QtCore.Qt.AlignCenter)
        self.page3_label.setWordWrap(True)
        self.page3_label.setObjectName("page3_label")
        self.verticalLayout_4.addWidget(self.page3_label)
        self.groupBox_2 = QtWidgets.QGroupBox(self.wizardPage3)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.groupBox_2.setFont(font)
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.GridLayout_2 = QtWidgets.QGridLayout()
        self.GridLayout_2.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.GridLayout_2.setContentsMargins(-1, 0, -1, 0)
        self.GridLayout_2.setObjectName("GridLayout_2")
        self.destinationAddressLabel = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.destinationAddressLabel.setFont(font)
        self.destinationAddressLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.destinationAddressLabel.setObjectName("destinationAddressLabel")
        self.GridLayout_2.addWidget(self.destinationAddressLabel, 3, 0, 1, 1)
        self.destinationAccountLabel = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.destinationAccountLabel.setFont(font)
        self.destinationAccountLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.destinationAccountLabel.setObjectName("destinationAccountLabel")
        self.GridLayout_2.addWidget(self.destinationAccountLabel, 1, 0, 1, 1)
        self.destinationDerivationValueLabel = QtWidgets.QLabel(self.groupBox_2)
        self.destinationDerivationValueLabel.setText("")
        self.destinationDerivationValueLabel.setObjectName("destinationDerivationValueLabel")
        self.GridLayout_2.addWidget(self.destinationDerivationValueLabel, 2, 1, 1, 1)
        self.destinationAccountComboBox = QtWidgets.QComboBox(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.destinationAccountComboBox.sizePolicy().hasHeightForWidth())
        self.destinationAccountComboBox.setSizePolicy(sizePolicy)
        self.destinationAccountComboBox.setObjectName("destinationAccountComboBox")
        self.GridLayout_2.addWidget(self.destinationAccountComboBox, 1, 1, 1, 1)
        self.destinationBalanceLabel = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.destinationBalanceLabel.setFont(font)
        self.destinationBalanceLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.destinationBalanceLabel.setObjectName("destinationBalanceLabel")
        self.GridLayout_2.addWidget(self.destinationBalanceLabel, 4, 0, 1, 1)
        self.destinationBalanceValueLabel = QtWidgets.QLabel(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.destinationBalanceValueLabel.sizePolicy().hasHeightForWidth())
        self.destinationBalanceValueLabel.setSizePolicy(sizePolicy)
        self.destinationBalanceValueLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);")
        self.destinationBalanceValueLabel.setObjectName("destinationBalanceValueLabel")
        self.GridLayout_2.addWidget(self.destinationBalanceValueLabel, 4, 1, 1, 1)
        self.destinationDerivationLabel = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.destinationDerivationLabel.setFont(font)
        self.destinationDerivationLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.destinationDerivationLabel.setObjectName("destinationDerivationLabel")
        self.GridLayout_2.addWidget(self.destinationDerivationLabel, 2, 0, 1, 1)
        self.destinationAddressValueLabel = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.destinationAddressValueLabel.setFont(font)
        self.destinationAddressValueLabel.setText("")
        self.destinationAddressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.destinationAddressValueLabel.setObjectName("destinationAddressValueLabel")
        self.GridLayout_2.addWidget(self.destinationAddressValueLabel, 3, 1, 1, 1)
        self.verticalLayout_3.addLayout(self.GridLayout_2)
        self.verticalLayout_4.addWidget(self.groupBox_2)
        self.destinationErrorLabel = QtWidgets.QLabel(self.wizardPage3)
        self.destinationErrorLabel.setText("")
        self.destinationErrorLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.destinationErrorLabel.setObjectName("destinationErrorLabel")
        self.verticalLayout_4.addWidget(self.destinationErrorLabel)
        importAccountV1Wizard.addPage(self.wizardPage3)
        self.wizardPage4 = QtWidgets.QWizardPage()
        self.wizardPage4.setObjectName("wizardPage4")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.wizardPage4)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.label = QtWidgets.QLabel(self.wizardPage4)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setWordWrap(True)
        self.label.setObjectName("label")
        self.verticalLayout_5.addWidget(self.label)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.sourceV1AddressValueImportLabel = QtWidgets.QLabel(self.wizardPage4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sourceV1AddressValueImportLabel.sizePolicy().hasHeightForWidth())
        self.sourceV1AddressValueImportLabel.setSizePolicy(sizePolicy)
        self.sourceV1AddressValueImportLabel.setText("")
        self.sourceV1AddressValueImportLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.sourceV1AddressValueImportLabel.setObjectName("sourceV1AddressValueImportLabel")
        self.gridLayout_2.addWidget(self.sourceV1AddressValueImportLabel, 1, 1, 1, 1)
        self.sourceV1AddressImportLabel = QtWidgets.QLabel(self.wizardPage4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sourceV1AddressImportLabel.sizePolicy().hasHeightForWidth())
        self.sourceV1AddressImportLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sourceV1AddressImportLabel.setFont(font)
        self.sourceV1AddressImportLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sourceV1AddressImportLabel.setObjectName("sourceV1AddressImportLabel")
        self.gridLayout_2.addWidget(self.sourceV1AddressImportLabel, 1, 0, 1, 1)
        self.sourceBalanceValueImportLabel = QtWidgets.QLabel(self.wizardPage4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sourceBalanceValueImportLabel.sizePolicy().hasHeightForWidth())
        self.sourceBalanceValueImportLabel.setSizePolicy(sizePolicy)
        self.sourceBalanceValueImportLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);")
        self.sourceBalanceValueImportLabel.setObjectName("sourceBalanceValueImportLabel")
        self.gridLayout_2.addWidget(self.sourceBalanceValueImportLabel, 3, 1, 1, 1)
        self.sourceBalanceImportLabel = QtWidgets.QLabel(self.wizardPage4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sourceBalanceImportLabel.setFont(font)
        self.sourceBalanceImportLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sourceBalanceImportLabel.setObjectName("sourceBalanceImportLabel")
        self.gridLayout_2.addWidget(self.sourceBalanceImportLabel, 3, 0, 1, 1)
        self.sourceIdentityImportLabel = QtWidgets.QLabel(self.wizardPage4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sourceIdentityImportLabel.setFont(font)
        self.sourceIdentityImportLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sourceIdentityImportLabel.setObjectName("sourceIdentityImportLabel")
        self.gridLayout_2.addWidget(self.sourceIdentityImportLabel, 4, 0, 1, 1)
        self.sourceIdentityValueImportLabel = QtWidgets.QLabel(self.wizardPage4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sourceIdentityValueImportLabel.sizePolicy().hasHeightForWidth())
        self.sourceIdentityValueImportLabel.setSizePolicy(sizePolicy)
        self.sourceIdentityValueImportLabel.setText("")
        self.sourceIdentityValueImportLabel.setObjectName("sourceIdentityValueImportLabel")
        self.gridLayout_2.addWidget(self.sourceIdentityValueImportLabel, 4, 1, 1, 1)
        self.sourceAddressImportLabel = QtWidgets.QLabel(self.wizardPage4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sourceAddressImportLabel.setFont(font)
        self.sourceAddressImportLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sourceAddressImportLabel.setObjectName("sourceAddressImportLabel")
        self.gridLayout_2.addWidget(self.sourceAddressImportLabel, 2, 0, 1, 1)
        self.sourceAddressValueImportLabel = QtWidgets.QLabel(self.wizardPage4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sourceAddressValueImportLabel.sizePolicy().hasHeightForWidth())
        self.sourceAddressValueImportLabel.setSizePolicy(sizePolicy)
        self.sourceAddressValueImportLabel.setText("")
        self.sourceAddressValueImportLabel.setObjectName("sourceAddressValueImportLabel")
        self.gridLayout_2.addWidget(self.sourceAddressValueImportLabel, 2, 1, 1, 1)
        self.sourceNameImportLabel = QtWidgets.QLabel(self.wizardPage4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sourceNameImportLabel.setFont(font)
        self.sourceNameImportLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sourceNameImportLabel.setObjectName("sourceNameImportLabel")
        self.gridLayout_2.addWidget(self.sourceNameImportLabel, 0, 0, 1, 1)
        self.sourceNameValueImportLabel = QtWidgets.QLabel(self.wizardPage4)
        self.sourceNameValueImportLabel.setText("")
        self.sourceNameValueImportLabel.setObjectName("sourceNameValueImportLabel")
        self.gridLayout_2.addWidget(self.sourceNameValueImportLabel, 0, 1, 1, 1)
        self.verticalLayout_5.addLayout(self.gridLayout_2)
        self.importButton = QtWidgets.QPushButton(self.wizardPage4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.importButton.sizePolicy().hasHeightForWidth())
        self.importButton.setSizePolicy(sizePolicy)
        self.importButton.setObjectName("importButton")
        self.verticalLayout_5.addWidget(self.importButton, 0, QtCore.Qt.AlignHCenter)
        self.ImportImagelabel = QtWidgets.QLabel(self.wizardPage4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ImportImagelabel.sizePolicy().hasHeightForWidth())
        self.ImportImagelabel.setSizePolicy(sizePolicy)
        self.ImportImagelabel.setMaximumSize(QtCore.QSize(64, 64))
        self.ImportImagelabel.setText("")
        self.ImportImagelabel.setPixmap(QtGui.QPixmap(":/images/arrow_down"))
        self.ImportImagelabel.setScaledContents(True)
        self.ImportImagelabel.setAlignment(QtCore.Qt.AlignCenter)
        self.ImportImagelabel.setObjectName("ImportImagelabel")
        self.verticalLayout_5.addWidget(self.ImportImagelabel, 0, QtCore.Qt.AlignHCenter)
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.destinationAddressImportLabel = QtWidgets.QLabel(self.wizardPage4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.destinationAddressImportLabel.setFont(font)
        self.destinationAddressImportLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.destinationAddressImportLabel.setObjectName("destinationAddressImportLabel")
        self.gridLayout_3.addWidget(self.destinationAddressImportLabel, 2, 0, 1, 1)
        self.destinationAddressValueImportLabel = QtWidgets.QLabel(self.wizardPage4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.destinationAddressValueImportLabel.sizePolicy().hasHeightForWidth())
        self.destinationAddressValueImportLabel.setSizePolicy(sizePolicy)
        self.destinationAddressValueImportLabel.setText("")
        self.destinationAddressValueImportLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.destinationAddressValueImportLabel.setObjectName("destinationAddressValueImportLabel")
        self.gridLayout_3.addWidget(self.destinationAddressValueImportLabel, 2, 1, 1, 1)
        self.destinationBalanceValueImportLabel = QtWidgets.QLabel(self.wizardPage4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.destinationBalanceValueImportLabel.sizePolicy().hasHeightForWidth())
        self.destinationBalanceValueImportLabel.setSizePolicy(sizePolicy)
        self.destinationBalanceValueImportLabel.setStyleSheet("color: white;\n"
"border : 3px solid rgb(34, 156, 244);\n"
"border-radius: 10%;\n"
"background: rgb(34, 156, 244);")
        self.destinationBalanceValueImportLabel.setObjectName("destinationBalanceValueImportLabel")
        self.gridLayout_3.addWidget(self.destinationBalanceValueImportLabel, 3, 1, 1, 1)
        self.destinationBalanceImportLabel = QtWidgets.QLabel(self.wizardPage4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.destinationBalanceImportLabel.setFont(font)
        self.destinationBalanceImportLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.destinationBalanceImportLabel.setObjectName("destinationBalanceImportLabel")
        self.gridLayout_3.addWidget(self.destinationBalanceImportLabel, 3, 0, 1, 1)
        self.destinationIdentityImportLabel = QtWidgets.QLabel(self.wizardPage4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.destinationIdentityImportLabel.setFont(font)
        self.destinationIdentityImportLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.destinationIdentityImportLabel.setObjectName("destinationIdentityImportLabel")
        self.gridLayout_3.addWidget(self.destinationIdentityImportLabel, 4, 0, 1, 1)
        self.destinationIdentityValueImportLabel = QtWidgets.QLabel(self.wizardPage4)
        self.destinationIdentityValueImportLabel.setText("")
        self.destinationIdentityValueImportLabel.setObjectName("destinationIdentityValueImportLabel")
        self.gridLayout_3.addWidget(self.destinationIdentityValueImportLabel, 4, 1, 1, 1)
        self.destinationNameImportLabel = QtWidgets.QLabel(self.wizardPage4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.destinationNameImportLabel.setFont(font)
        self.destinationNameImportLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.destinationNameImportLabel.setObjectName("destinationNameImportLabel")
        self.gridLayout_3.addWidget(self.destinationNameImportLabel, 1, 0, 1, 1)
        self.destinationNameValueImportLabel = QtWidgets.QLabel(self.wizardPage4)
        self.destinationNameValueImportLabel.setText("")
        self.destinationNameValueImportLabel.setObjectName("destinationNameValueImportLabel")
        self.gridLayout_3.addWidget(self.destinationNameValueImportLabel, 1, 1, 1, 1)
        self.verticalLayout_5.addLayout(self.gridLayout_3)
        self.importErrorLabel = QtWidgets.QLabel(self.wizardPage4)
        self.importErrorLabel.setText("")
        self.importErrorLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.importErrorLabel.setObjectName("importErrorLabel")
        self.verticalLayout_5.addWidget(self.importErrorLabel)
        importAccountV1Wizard.addPage(self.wizardPage4)

        self.retranslateUi(importAccountV1Wizard)
        QtCore.QMetaObject.connectSlotsByName(importAccountV1Wizard)
        importAccountV1Wizard.setTabOrder(self.destinationAccountComboBox, self.importButton)

    def retranslateUi(self, importAccountV1Wizard):
        #  _translate = QtCore.QCoreApplication.translate
        importAccountV1Wizard.setWindowTitle(_("Wizard to transfer a V1 account into a V2 account"))
        self.page1_label.setText(_("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:22pt;\">This wizard will help you to transfer a V1 account into a V2 account.</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:22pt;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:16pt;\">Identity and money will be transfered from the V1 account to the</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:16pt;\">V2 account.</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600; font-style:italic;\">V1 account: </span><span style=\" font-style:italic;\">A V1 account is an Ğ1 account generated by a secret ID and a password (ex: Cesium V1).</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-style:italic;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600; font-style:italic;\">V2 Account:</span><span style=\" font-style:italic;\"> A V2 account is an account generated by a twelve-word restoration code (also called mnemonic).</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>"))
        self.page2_label.setText(_("Please select the V1 source account"))
        self.groupBox.setTitle(_("V1 Source Account"))
        self.sourceV1AddressLabel.setText(_("V1 Address"))
        self.sourceAddressLabel.setText(_("Address"))
        self.sourceBalanceValueLabel.setText(_("?"))
        self.sourceIdentityLabel.setText(_("Identity"))
        self.sourceBalanceLabel.setText(_("Balance"))
        self.sourceV1AccountLabel.setText(_("V1 Account"))
        self.page3_label.setText(_("Please select the V2 destination account"))
        self.groupBox_2.setTitle(_("V2 Destination Account"))
        self.destinationAddressLabel.setText(_("Address"))
        self.destinationAccountLabel.setText(_("V2 account"))
        self.destinationBalanceLabel.setText(_("Balance"))
        self.destinationBalanceValueLabel.setText(_("?"))
        self.destinationDerivationLabel.setText(_("Derivation"))
        self.label.setText(_("Click on the transfer account button and wait for the status message"))
        self.sourceV1AddressImportLabel.setText(_("V1 Address"))
        self.sourceBalanceValueImportLabel.setText(_("?"))
        self.sourceBalanceImportLabel.setText(_("Balance"))
        self.sourceIdentityImportLabel.setText(_("Identity"))
        self.sourceAddressImportLabel.setText(_("Address"))
        self.sourceNameImportLabel.setText(_("Name"))
        self.importButton.setText(_("Transfer account"))
        self.destinationAddressImportLabel.setText(_("Address"))
        self.destinationBalanceValueImportLabel.setText(_("?"))
        self.destinationBalanceImportLabel.setText(_("Balance"))
        self.destinationIdentityImportLabel.setText(_("Identity"))
        self.destinationNameImportLabel.setText(_("Name"))
import tikka.slots.pyqt.resources.icons.index_rc
