# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/windows/v1_wallet_restore_from_file.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_V1WalletRestoreFromFileDialog(object):
    def setupUi(self, V1WalletRestoreFromFileDialog):
        V1WalletRestoreFromFileDialog.setObjectName("V1WalletRestoreFromFileDialog")
        V1WalletRestoreFromFileDialog.resize(591, 538)
        V1WalletRestoreFromFileDialog.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.verticalLayout = QtWidgets.QVBoxLayout(V1WalletRestoreFromFileDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.imageLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        self.imageLabel.setMaximumSize(QtCore.QSize(200, 200))
        self.imageLabel.setText("")
        self.imageLabel.setPixmap(QtGui.QPixmap(":/images/keys"))
        self.imageLabel.setScaledContents(True)
        self.imageLabel.setObjectName("imageLabel")
        self.verticalLayout.addWidget(self.imageLabel, 0, QtCore.Qt.AlignHCenter)
        self.browseFilesButton = QtWidgets.QPushButton(V1WalletRestoreFromFileDialog)
        self.browseFilesButton.setAutoExclusive(False)
        self.browseFilesButton.setObjectName("browseFilesButton")
        self.verticalLayout.addWidget(self.browseFilesButton, 0, QtCore.Qt.AlignHCenter)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.showButton = QtWidgets.QPushButton(V1WalletRestoreFromFileDialog)
        self.showButton.setObjectName("showButton")
        self.gridLayout.addWidget(self.showButton, 1, 2, 1, 1)
        self.filePasswordLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.filePasswordLabel.setFont(font)
        self.filePasswordLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.filePasswordLabel.setObjectName("filePasswordLabel")
        self.gridLayout.addWidget(self.filePasswordLabel, 1, 0, 1, 1)
        self.v1AddressLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.v1AddressLabel.setFont(font)
        self.v1AddressLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.v1AddressLabel.setObjectName("v1AddressLabel")
        self.gridLayout.addWidget(self.v1AddressLabel, 2, 0, 1, 1)
        self.v1AddressValueLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        self.v1AddressValueLabel.setText("")
        self.v1AddressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.v1AddressValueLabel.setObjectName("v1AddressValueLabel")
        self.gridLayout.addWidget(self.v1AddressValueLabel, 2, 1, 1, 1)
        self.filePasswordLineEdit = QtWidgets.QLineEdit(V1WalletRestoreFromFileDialog)
        self.filePasswordLineEdit.setEchoMode(QtWidgets.QLineEdit.Password)
        self.filePasswordLineEdit.setObjectName("filePasswordLineEdit")
        self.gridLayout.addWidget(self.filePasswordLineEdit, 1, 1, 1, 1)
        self.pathLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.pathLabel.setFont(font)
        self.pathLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.pathLabel.setObjectName("pathLabel")
        self.gridLayout.addWidget(self.pathLabel, 0, 0, 1, 1)
        self.pathValueLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        self.pathValueLabel.setText("")
        self.pathValueLabel.setObjectName("pathValueLabel")
        self.gridLayout.addWidget(self.pathValueLabel, 0, 1, 1, 1)
        self.addressLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.addressLabel.setFont(font)
        self.addressLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.addressLabel.setObjectName("addressLabel")
        self.gridLayout.addWidget(self.addressLabel, 3, 0, 1, 1)
        self.addressValueLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        self.addressValueLabel.setText("")
        self.addressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.addressValueLabel.setObjectName("addressValueLabel")
        self.gridLayout.addWidget(self.addressValueLabel, 3, 1, 1, 1)
        self.nameLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.nameLabel.setFont(font)
        self.nameLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.nameLabel.setObjectName("nameLabel")
        self.gridLayout.addWidget(self.nameLabel, 4, 0, 1, 1)
        self.nameValueLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        self.nameValueLabel.setText("")
        self.nameValueLabel.setObjectName("nameValueLabel")
        self.gridLayout.addWidget(self.nameValueLabel, 4, 1, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout)
        self.errorLabel = QtWidgets.QLabel(V1WalletRestoreFromFileDialog)
        self.errorLabel.setStyleSheet("color: rgb(255, 0, 0)")
        self.errorLabel.setText("")
        self.errorLabel.setObjectName("errorLabel")
        self.verticalLayout.addWidget(self.errorLabel, 0, QtCore.Qt.AlignHCenter)
        self.storedPasswordFrame = QtWidgets.QFrame(V1WalletRestoreFromFileDialog)
        self.storedPasswordFrame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.storedPasswordFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.storedPasswordFrame.setObjectName("storedPasswordFrame")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.storedPasswordFrame)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.storedPasswordLabel = QtWidgets.QLabel(self.storedPasswordFrame)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.storedPasswordLabel.setFont(font)
        self.storedPasswordLabel.setObjectName("storedPasswordLabel")
        self.horizontalLayout_2.addWidget(self.storedPasswordLabel, 0, QtCore.Qt.AlignRight)
        self.storedpasswordLineEdit = QtWidgets.QLineEdit(self.storedPasswordFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.storedpasswordLineEdit.sizePolicy().hasHeightForWidth())
        self.storedpasswordLineEdit.setSizePolicy(sizePolicy)
        self.storedpasswordLineEdit.setMaxLength(20)
        self.storedpasswordLineEdit.setEchoMode(QtWidgets.QLineEdit.Password)
        self.storedpasswordLineEdit.setAlignment(QtCore.Qt.AlignCenter)
        self.storedpasswordLineEdit.setReadOnly(True)
        self.storedpasswordLineEdit.setObjectName("storedpasswordLineEdit")
        self.horizontalLayout_2.addWidget(self.storedpasswordLineEdit, 0, QtCore.Qt.AlignHCenter)
        self.storedPasswordHintLabel = QtWidgets.QLabel(self.storedPasswordFrame)
        font = QtGui.QFont()
        font.setItalic(True)
        self.storedPasswordHintLabel.setFont(font)
        self.storedPasswordHintLabel.setObjectName("storedPasswordHintLabel")
        self.horizontalLayout_2.addWidget(self.storedPasswordHintLabel, 0, QtCore.Qt.AlignLeft)
        self.verticalLayout.addWidget(self.storedPasswordFrame)
        self.passwordFrame = QtWidgets.QFrame(V1WalletRestoreFromFileDialog)
        self.passwordFrame.setObjectName("passwordFrame")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.passwordFrame)
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.passwordLabel = QtWidgets.QLabel(self.passwordFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.passwordLabel.sizePolicy().hasHeightForWidth())
        self.passwordLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.passwordLabel.setFont(font)
        self.passwordLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.passwordLabel.setObjectName("passwordLabel")
        self.horizontalLayout.addWidget(self.passwordLabel, 0, QtCore.Qt.AlignRight)
        self.passwordLineEdit = QtWidgets.QLineEdit(self.passwordFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.passwordLineEdit.sizePolicy().hasHeightForWidth())
        self.passwordLineEdit.setSizePolicy(sizePolicy)
        self.passwordLineEdit.setEchoMode(QtWidgets.QLineEdit.Password)
        self.passwordLineEdit.setAlignment(QtCore.Qt.AlignCenter)
        self.passwordLineEdit.setReadOnly(True)
        self.passwordLineEdit.setObjectName("passwordLineEdit")
        self.horizontalLayout.addWidget(self.passwordLineEdit, 0, QtCore.Qt.AlignHCenter)
        self.changeButton = QtWidgets.QPushButton(self.passwordFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.changeButton.sizePolicy().hasHeightForWidth())
        self.changeButton.setSizePolicy(sizePolicy)
        self.changeButton.setObjectName("changeButton")
        self.horizontalLayout.addWidget(self.changeButton, 0, QtCore.Qt.AlignLeft)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem2)
        self.verticalLayout.addWidget(self.passwordFrame)
        self.buttonBox = QtWidgets.QDialogButtonBox(V1WalletRestoreFromFileDialog)
        self.buttonBox.setEnabled(True)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox, 0, QtCore.Qt.AlignHCenter)

        self.retranslateUi(V1WalletRestoreFromFileDialog)
        self.buttonBox.rejected.connect(V1WalletRestoreFromFileDialog.reject) # type: ignore
        self.buttonBox.accepted.connect(V1WalletRestoreFromFileDialog.accept) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(V1WalletRestoreFromFileDialog)
        V1WalletRestoreFromFileDialog.setTabOrder(self.browseFilesButton, self.filePasswordLineEdit)
        V1WalletRestoreFromFileDialog.setTabOrder(self.filePasswordLineEdit, self.storedpasswordLineEdit)
        V1WalletRestoreFromFileDialog.setTabOrder(self.storedpasswordLineEdit, self.passwordLineEdit)
        V1WalletRestoreFromFileDialog.setTabOrder(self.passwordLineEdit, self.changeButton)
        V1WalletRestoreFromFileDialog.setTabOrder(self.changeButton, self.showButton)

    def retranslateUi(self, V1WalletRestoreFromFileDialog):
        #  _translate = QtCore.QCoreApplication.translate
        V1WalletRestoreFromFileDialog.setWindowTitle(_("Restore V1 wallet from file"))
        self.browseFilesButton.setText(_("Browse files..."))
        self.showButton.setText(_("Show"))
        self.filePasswordLabel.setText(_("File Password"))
        self.v1AddressLabel.setText(_("V1 address"))
        self.pathLabel.setText(_("Path"))
        self.addressLabel.setText(_("Address"))
        self.nameLabel.setText(_("Name"))
        self.storedPasswordLabel.setText(_("Password"))
        self.storedPasswordHintLabel.setText(_("Wallet will be locked with the current password"))
        self.passwordLabel.setText(_("Password"))
        self.changeButton.setText(_("Change"))
import tikka.slots.pyqt.resources.icons.index_rc
