# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/widgets/account_table.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_AccountTableWidget(object):
    def setupUi(self, AccountTableWidget):
        AccountTableWidget.setObjectName("AccountTableWidget")
        AccountTableWidget.resize(684, 329)
        AccountTableWidget.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.verticalLayout = QtWidgets.QVBoxLayout(AccountTableWidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.refreshButton = QtWidgets.QPushButton(AccountTableWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.refreshButton.sizePolicy().hasHeightForWidth())
        self.refreshButton.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/refresh_icon"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refreshButton.setIcon(icon)
        self.refreshButton.setObjectName("refreshButton")
        self.verticalLayout.addWidget(self.refreshButton, 0, QtCore.Qt.AlignRight)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.errorLabel = QtWidgets.QLabel(AccountTableWidget)
        self.errorLabel.setStyleSheet("color: red")
        self.errorLabel.setText("")
        self.errorLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.errorLabel.setObjectName("errorLabel")
        self.horizontalLayout_3.addWidget(self.errorLabel)
        self.totalBalanceValueLabel = QtWidgets.QLabel(AccountTableWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.totalBalanceValueLabel.sizePolicy().hasHeightForWidth())
        self.totalBalanceValueLabel.setSizePolicy(sizePolicy)
        self.totalBalanceValueLabel.setText("")
        self.totalBalanceValueLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.totalBalanceValueLabel.setObjectName("totalBalanceValueLabel")
        self.horizontalLayout_3.addWidget(self.totalBalanceValueLabel)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.filtersGroupBox = QtWidgets.QGroupBox(AccountTableWidget)
        self.filtersGroupBox.setAutoFillBackground(False)
        self.filtersGroupBox.setStyleSheet("")
        self.filtersGroupBox.setFlat(False)
        self.filtersGroupBox.setObjectName("filtersGroupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.filtersGroupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.categoryLabel = QtWidgets.QLabel(self.filtersGroupBox)
        self.categoryLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.categoryLabel.setObjectName("categoryLabel")
        self.horizontalLayout.addWidget(self.categoryLabel)
        self.categoryComboBox = QtWidgets.QComboBox(self.filtersGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.categoryComboBox.sizePolicy().hasHeightForWidth())
        self.categoryComboBox.setSizePolicy(sizePolicy)
        self.categoryComboBox.setObjectName("categoryComboBox")
        self.horizontalLayout.addWidget(self.categoryComboBox)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.walletLabel = QtWidgets.QLabel(self.filtersGroupBox)
        self.walletLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.walletLabel.setObjectName("walletLabel")
        self.horizontalLayout_2.addWidget(self.walletLabel)
        self.walletComboBox = QtWidgets.QComboBox(self.filtersGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.walletComboBox.sizePolicy().hasHeightForWidth())
        self.walletComboBox.setSizePolicy(sizePolicy)
        self.walletComboBox.setObjectName("walletComboBox")
        self.horizontalLayout_2.addWidget(self.walletComboBox)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.verticalLayout.addWidget(self.filtersGroupBox)
        self.tableView = QtWidgets.QTableView(AccountTableWidget)
        self.tableView.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tableView.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.tableView.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustIgnored)
        self.tableView.setAutoScroll(True)
        self.tableView.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tableView.setAlternatingRowColors(True)
        self.tableView.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableView.setShowGrid(False)
        self.tableView.setSortingEnabled(False)
        self.tableView.setObjectName("tableView")
        self.tableView.horizontalHeader().setMinimumSectionSize(50)
        self.tableView.horizontalHeader().setStretchLastSection(True)
        self.tableView.verticalHeader().setVisible(False)
        self.tableView.verticalHeader().setCascadingSectionResizes(True)
        self.tableView.verticalHeader().setDefaultSectionSize(0)
        self.verticalLayout.addWidget(self.tableView)

        self.retranslateUi(AccountTableWidget)
        QtCore.QMetaObject.connectSlotsByName(AccountTableWidget)
        AccountTableWidget.setTabOrder(self.categoryComboBox, self.walletComboBox)
        AccountTableWidget.setTabOrder(self.walletComboBox, self.tableView)

    def retranslateUi(self, AccountTableWidget):
        #  _translate = QtCore.QCoreApplication.translate
        AccountTableWidget.setWindowTitle(_("Account table"))
        self.refreshButton.setText(_("Refresh"))
        self.filtersGroupBox.setTitle(_("Filters"))
        self.categoryLabel.setText(_("Category"))
        self.walletLabel.setText(_("Wallet"))
import tikka.slots.pyqt.resources.icons.index_rc
