ALTER TABLE currency ADD COLUMN certification_number_to_be_member integer;
ALTER TABLE currency ADD COLUMN minimum_delay_between_two_membership_renewals integer;
ALTER TABLE currency ADD COLUMN validity_duration_of_membership integer;
ALTER TABLE currency ADD COLUMN minimum_certifications_received_to_be_certifier integer;
ALTER TABLE currency ADD COLUMN validity_duration_of_certification integer;
ALTER TABLE currency ADD COLUMN minimum_delay_between_two_certifications integer;
ALTER TABLE currency ADD COLUMN maximum_number_of_certifications_per_member integer;
ALTER TABLE currency ADD COLUMN maximum_distance_in_step integer;
ALTER TABLE currency ADD COLUMN minimum_percentage_of_remote_referral_members_to_be_member integer;
ALTER TABLE currency ADD COLUMN identity_automatic_revocation_period integer;
ALTER TABLE currency ADD COLUMN minimum_delay_between_changing_identity_owner integer;
ALTER TABLE currency ADD COLUMN confirm_identity_period integer;
ALTER TABLE currency ADD COLUMN identity_deletion_after_revocation integer;
ALTER TABLE currency ADD COLUMN minimum_delay_between_identity_creation integer;
ALTER TABLE currency ADD COLUMN identity_validation_period integer;
ALTER TABLE currency ADD COLUMN maximum_certifications_per_smith integer;
ALTER TABLE currency ADD COLUMN number_of_certifications_to_become_smith integer;
ALTER TABLE currency ADD COLUMN maximum_inactivity_duration_allowed_for_smith integer;
