# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/windows/wallet_save.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_WalletSaveDialog(object):
    def setupUi(self, WalletSaveDialog):
        WalletSaveDialog.setObjectName("WalletSaveDialog")
        WalletSaveDialog.resize(747, 355)
        self.verticalLayout = QtWidgets.QVBoxLayout(WalletSaveDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.imageLabel = QtWidgets.QLabel(WalletSaveDialog)
        self.imageLabel.setMaximumSize(QtCore.QSize(200, 200))
        self.imageLabel.setText("")
        self.imageLabel.setPixmap(QtGui.QPixmap(":/images/keys"))
        self.imageLabel.setScaledContents(True)
        self.imageLabel.setObjectName("imageLabel")
        self.verticalLayout.addWidget(self.imageLabel, 0, QtCore.Qt.AlignHCenter)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.addressLabel = QtWidgets.QLabel(WalletSaveDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.addressLabel.setFont(font)
        self.addressLabel.setObjectName("addressLabel")
        self.gridLayout.addWidget(self.addressLabel, 0, 0, 1, 1)
        self.passwordLineEdit = QtWidgets.QLineEdit(WalletSaveDialog)
        self.passwordLineEdit.setText("")
        self.passwordLineEdit.setAlignment(QtCore.Qt.AlignCenter)
        self.passwordLineEdit.setReadOnly(True)
        self.passwordLineEdit.setObjectName("passwordLineEdit")
        self.gridLayout.addWidget(self.passwordLineEdit, 2, 1, 1, 1)
        self.fileFormatLabel = QtWidgets.QLabel(WalletSaveDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.fileFormatLabel.setFont(font)
        self.fileFormatLabel.setObjectName("fileFormatLabel")
        self.gridLayout.addWidget(self.fileFormatLabel, 1, 0, 1, 1)
        self.passwordLabel = QtWidgets.QLabel(WalletSaveDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.passwordLabel.setFont(font)
        self.passwordLabel.setObjectName("passwordLabel")
        self.gridLayout.addWidget(self.passwordLabel, 2, 0, 1, 1)
        self.addressValueLabel = QtWidgets.QLabel(WalletSaveDialog)
        self.addressValueLabel.setText("")
        self.addressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.addressValueLabel.setObjectName("addressValueLabel")
        self.gridLayout.addWidget(self.addressValueLabel, 0, 1, 1, 1)
        self.fileFormatValueLabel = QtWidgets.QLabel(WalletSaveDialog)
        self.fileFormatValueLabel.setObjectName("fileFormatValueLabel")
        self.gridLayout.addWidget(self.fileFormatValueLabel, 1, 1, 1, 1)
        self.changeButton = QtWidgets.QPushButton(WalletSaveDialog)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/refresh_icon"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.changeButton.setIcon(icon)
        self.changeButton.setObjectName("changeButton")
        self.gridLayout.addWidget(self.changeButton, 2, 2, 1, 1, QtCore.Qt.AlignLeft)
        self.verticalLayout.addLayout(self.gridLayout)
        self.browseFilesButton = QtWidgets.QPushButton(WalletSaveDialog)
        self.browseFilesButton.setObjectName("browseFilesButton")
        self.verticalLayout.addWidget(self.browseFilesButton, 0, QtCore.Qt.AlignHCenter)
        self.errorLabel = QtWidgets.QLabel(WalletSaveDialog)
        self.errorLabel.setStyleSheet("color: red;")
        self.errorLabel.setText("")
        self.errorLabel.setObjectName("errorLabel")
        self.verticalLayout.addWidget(self.errorLabel, 0, QtCore.Qt.AlignHCenter)

        self.retranslateUi(WalletSaveDialog)
        QtCore.QMetaObject.connectSlotsByName(WalletSaveDialog)

    def retranslateUi(self, WalletSaveDialog):
        #  _translate = QtCore.QCoreApplication.translate
        WalletSaveDialog.setWindowTitle(_("Save wallet"))
        self.addressLabel.setText(_("Address"))
        self.fileFormatLabel.setText(_("File format"))
        self.passwordLabel.setText(_("Password"))
        self.fileFormatValueLabel.setText(_("EWIF"))
        self.changeButton.setText(_("Change"))
        self.browseFilesButton.setText(_("Browse files..."))
import tikka.slots.pyqt.resources.icons.index_rc
